pub enum BusinessDayConvention {
Unadjusted,
Following,
ModifiedFollowing,
Preceding,
ModifiedPreceding,
}Expand description
How a date falling on a non-business day is adjusted.
Variants
Unadjusted
Leave the date as it is.
Following
Move to the next business day.
ModifiedFollowing
Move to the next business day unless that crosses into the next calendar month, in which case move to the preceding business day.
Preceding
Move to the previous business day.
ModifiedPreceding
Move to the previous business day unless that crosses into the previous calendar month, in which case move to the following one.