pub struct CurvePillar {
pub date: Option<NaiveDate>,
pub time: f64,
pub df: f64,
pub zero_rate: f64,
}Expand description
One pillar of the curve, with the zero rate derived for inspection.
Fields
date: Option<NaiveDate>Original pillar date, when the curve was built from date tenors.
time: f64df: f64zero_rate: f64Continuously compounded zero rate at this pillar.