EquityInstrumentBase

Struct EquityInstrumentBase 

pub struct EquityInstrumentBase {
    pub symbol: String,
    pub currency: Option<String>,
    pub exchange: Option<String>,
    pub name: Option<String>,
    pub cusip: Option<String>,
    pub isin: Option<String>,
    pub underlying_price: f64,
    pub long_short: Option<i32>,
    pub risk_free_rate: Option<f64>,
    pub borrow_cost: Option<f64>,
    pub settlement_type: Option<String>,
    pub valuation_date: Option<String>,
}

Fields

symbol: Stringcurrency: Option<String>exchange: Option<String>name: Option<String>cusip: Option<String>isin: Option<String>underlying_price: f64long_short: Option<i32>risk_free_rate: Option<f64>borrow_cost: Option<f64>

Continuous stock borrow (repo) cost; enters the carry like an additional dividend yield (hard-to-borrow lowers the forward).

settlement_type: Option<String>valuation_date: Option<String>

Pricing as-of date (YYYY-MM-DD). Defaults to today, but setting it makes the contract price reproducibly and allows re-marking a book as of any date.