pub fn parse<T: DeserializeOwned>(
content: &str,
format: Format,
) -> Result<T, RustyQLibError>Expand description
Parse a document into any deserializable type, in either format.
pub fn parse<T: DeserializeOwned>(
content: &str,
format: Format,
) -> Result<T, RustyQLibError>Parse a document into any deserializable type, in either format.