pub fn volga(option: &EquityOption) -> f64Expand description
Volga as the second price derivative under a parallel vol bump (the larger step tempers roundoff in the second difference).
pub fn volga(option: &EquityOption) -> f64Volga as the second price derivative under a parallel vol bump (the larger step tempers roundoff in the second difference).