Module blackscholes

Module blackscholes 

Structs

BlackScholesPricer

Functions

bs_charm
Black-Scholes charm, the change in spot delta per year of calendar time.
bs_price
Black-Scholes price of a European vanilla as a pure function of its inputs (no option object needed).
bs_vanna
Black-Scholes vanna, the change in spot delta per unit of volatility.
bs_vega
Black-Scholes vega as a pure function (per unit of vol).
bs_volga
Black-Scholes volga (vomma), the change in vega per unit of volatility, vega * d1 * d2 / sigma. Same for calls and puts (parity is volatility-independent); negative at the money, positive in the wings.
bs_zomma
Black-Scholes zomma, the change in spot gamma per unit of volatility.
implied_vol_from_price
Implied Black-Scholes volatility for a European vanilla price.