Module equity_forward

Module equity_forward 

Structs

EquityForward
A forward contract is an agreement between two parties to buy or sell, as the case may be, a commodity (or financial instrument or currency or any other underlying) on a pre-determined future date at a price agreed when the contract is entered into.