Module parse_contracts

Module parse_contracts 

Functions

build_curve
This function different types of curves such as term structure, volatility surface, etc.
parse_contract
Price every contract in a document. The input format is detected from the content (JSON or XML) and the output format from the output file extension, defaulting to the input format.
process_contract
save_to_file
This function saves the output to a file and returns the path to the file.