pub fn numeric_diffusion_dx<P: StochasticProcess1D + ?Sized>(
p: &P,
t: f64,
x: f64,
) -> f64Expand description
Central finite difference of the diffusion coefficient in the state —
the default for StochasticProcess1D::diffusion_dx, callable from
implementations that override it for one branch of their dynamics.