pub struct EquityForward {Show 16 fields
pub symbol: String,
pub currency: Option<String>,
pub exchange: Option<String>,
pub name: Option<String>,
pub cusip: Option<String>,
pub isin: Option<String>,
pub settlement_type: Option<String>,
pub underlying_price: Quote,
pub forward_price: Quote,
pub risk_free_rate: f64,
pub dividend_yield: f64,
pub borrow_cost: f64,
pub maturity_date: NaiveDate,
pub valuation_date: NaiveDate,
pub long_short: LongShort,
pub notional: f64,
}Expand description
A forward contract is an agreement between two parties to buy or sell, as the case may be, a commodity (or financial instrument or currency or any other underlying) on a pre-determined future date at a price agreed when the contract is entered into.
Fields
symbol: Stringcurrency: Option<String>exchange: Option<String>name: Option<String>cusip: Option<String>isin: Option<String>settlement_type: Option<String>underlying_price: Quoteforward_price: Quoterisk_free_rate: f64dividend_yield: f64borrow_cost: f64Continuous stock borrow (repo) cost; part of the carry.
maturity_date: NaiveDatevaluation_date: NaiveDatelong_short: LongShortnotional: f64Implementations
Sourceimpl EquityForward
impl EquityForward
Sourcepub fn from_json(data: &EquityForwardData) -> Box<Self>
pub fn from_json(data: &EquityForwardData) -> Box<Self>
Build from contract data, panicking on any invalid field. Fallible
callers should use EquityForward::try_from_json.
pub fn try_from_json( data: &EquityForwardData, ) -> Result<Box<Self>, RustyQLibError>
Sourceimpl EquityForward
impl EquityForward