pub struct ForwardStartPayoff {
pub put_or_call: PutOrCall,
pub exercise_style: ContractStyle,
pub strike_fraction: f64,
pub start_fraction: f64,
}Fields
put_or_call: PutOrCallexercise_style: ContractStylestrike_fraction: f64Strike as a fraction of the spot on the fixing date (1.0 = at the money).
start_fraction: f64Fixing time as a fraction of the option life, in (0, 1).