Functions
- build_
curve - This function different types of curves such as term structure, volatility surface, etc.
- parse_
contract - Price every contract in a document. The input format is detected from the content (JSON or XML) and the output format from the output file extension, defaulting to the input format.
- process_
contract - save_
to_ file - This function saves the output to a file and returns the path to the file.