pub fn parse_contract(file: &mut File, output_filename: &str)Expand description
Price every contract in a document. The input format is detected from the content (JSON or XML) and the output format from the output file extension, defaulting to the input format.